@@ -1,5 +1,5 @@
 import datetime
-from client import BloombergClient
+from npd_cat_corr.client import BloombergClient
 import pandas as pd
 import os
 import calendar
